@@ -1,6 +1,6 @@
 use std::convert::TryInto;
 
-use clap::ArgMatches;
+use clap::{App, Arg, ArgMatches};
 use miette::Result;
 use mit_commit_message_lints::{
     console::style::to_be_piped,
@@ -9,6 +9,19 @@ use mit_commit_message_lints::{
 };
 
 use crate::{current_dir, get_vcs};
+
+pub fn app<'help>() -> App<'help> {
+    App::new("generate")
+        .arg(
+            Arg::new("scope")
+                .long("scope")
+                .short('s')
+                .possible_values(&["local", "global"])
+                .default_value("local"),
+        )
+        .about("Generate the config file for your current settings")
+}
+
 pub fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
     matches
         .subcommand_matches("lint")
